==> MVar_2.0.2.tar.gz: MVar/R/Plot.Regr_English.R <==
Plot.Regr <- function(Reg, TypeGraf = "Scatterplot", Title = NA, xlabel = NA, 
                      ylabel = NA, NameVarY = NA, NameVarX = NA, Color = TRUE, 
                      IntConf = TRUE, IntPrev = TRUE, Casc = TRUE) {
  # Esta funcao gera graficos da Analise de Regressao
  # desenvolvida por Paulo Cesar Ossani em 06/2016
    
  # Entrada:
  # Reg      - Dados da funcao de regressao.
  # TypeGraf - Tipo de grafico: 
  #            "Scatterplot" - Grafico de dispersao 2 a 2,
  #            "Regression"  - Grafico da regressao linear,
  #            "QQPlot"      - Grafico de probabilidade normal dos residuos,
  #            "Histogram"   - Histograma dos residuos,
  #            "Fits"        - Grafico dos valores ajustados versus os residuos,
  #            "Order"       - Grafico da ordem das observacoes versus os residuos.
  # Title    - Titulos para os graficos, se nulo retorna padrao.
  # xlabel   - Nomeia o eixo X, se nulo retorna padrao.
  # ylabel   - Nomeia o eixo Y, se nulo retorna padrao.
  # NameVarY - Nome da variavel Y, se nulo retorna padrao.
  # NameVarX - Nome da variavel, ou variaveis X, se nulo retorna padrao.
  # Color    - Graficos coloridos (default = TRUE).
  # IntConf  - Caso TypeGraf = "Regression":
  #            Graficos com intervalo de confianca (default = TRUE).
  # IntPrev  - Caso TypeGraf = "Regression":
  #            Graficos com intervalo de previsao (default = TRUE).
  # Casc    - Efeito cascata na apresentacao dos graficos (default = TRUE).

  # Retorna:
  # Varios graficos.

  Graphic <- c("Scatterplot", "Regression", "QQPlot", "Histogram", "Fits", "Order")
  if (is.na(pmatch(TypeGraf, Graphic))) 
     stop("'TypeGraf' input is incorrect, it should be: 'Scatterplot', 
          'Regression', 'QQPlot', 'Histogram', 'Fits' ou 'Order'. Verify!")

  if (!is.character(xlabel) && !is.na(xlabel))
     stop("'xlabel' input is incorrect, it should be of type character or string. Verify!")
  
  if (!is.character(ylabel) && !is.na(ylabel))
     stop("'ylabel' input is incorrect, it should be of type character or string. Verify!")
  
  if (!is.logical(Color))
     stop("'Color' input is incorrect, it should be TRUE or FALSE. Verify!")

  if (!is.logical(IntConf))
     stop("'IntConf' input is incorrect, it should be TRUE or FALSE. Verify!")

  if (!is.logical(IntPrev))
     stop("'IntPrev' input is incorrect, it should be TRUE or FALSE. Verify!")
 
  if (Reg$Intercepts) X <- as.matrix(Reg$X[,2:ncol(Reg$X)]) else X <- as.matrix(Reg$X)
  
  if (is.na(NameVarY))
     NameVarY <- c("Y")
  
  if (is.na(NameVarX))
     NameVarX <- c(paste("X",1:ncol(X),sep=""))
  
  if (!is.logical(Casc))
     stop("'Casc' input is incorrect, it should be TRUE or FALSE. Verify!")
  
  ## Inicio - Scatterplot
  if (TypeGraf == "Scatterplot") {
    
     if (is.na(Title))
        Title = c("Scatterplot 2 to 2")
     
     if (Casc) dev.new() # efeito cascata na apresentacao dos graficos
     
     Dat <- as.data.frame(cbind(Reg$Y,X))
     colnames(Dat) <- c(NameVarY,NameVarX)
     if (Color) cor <- c(2:(ncol(X)+1)) else cor <- c(rep("black", ncol(X)))
     pairs(Dat, # Scatterplot
           main = Title, # Titulo
           pch  = 21,    # Formato dos pontos 
           cex  = 1,     # Tamanho dos pontos
           bg   = cor)
  }
  ## Fim - Scatterplot
  
  ## Inicio - Grafico da regressao
  if (TypeGraf == "Regression") {
     if (ncol(X)!=1) 
        print("Warning! The regression graph is only possible for a regressor variable.")
    
     if (ncol(X)==1) { # para calculos de regressao simples
        
        if (is.na(xlabel))
           xlabel = "X-Axis"  # Nomeia Eixo X  
       
        if (is.na(ylabel))
           ylabel = "Y-Axis"  # Nomeia Eixo Y
        
        if (is.na(Title))
           Title = c("Linear regression graph")
        
        X <- as.numeric(X)
        
        if (Reg$Intercepts) Modelo <- lm(Y~X) else Modelo <- lm(Y~-1+X)
        
        if (Casc) dev.new() # efeito cascata na apresentacao dos graficos
        
        # Intervalo para abcissa
        Inter <- ifelse(length(Reg$Y)<100,150,length(Reg$Y)*1.5) # intervalo para o eixo X
        New.X <- data.frame(X=seq(min(X), max(X), by=((max(X)-min(X))/Inter)))
        
        # Predicao
        Predicao  <- predict(Modelo, New.X)
        
        # Intervalo de confianca
        Inter.Conf <- predict(Modelo, New.X, level=0.95, interval=c("confidence"))
        
        # Intervalo de Predicao
        Inter.Pred <- predict(Modelo, New.X, level=0.95, interval=c("prediction"))  
        
        plot(X,Reg$Y, # cria grafico
             xlab = xlabel, # Nomeia Eixo X
             ylab = ylabel, # Nomeia Eixo Y
             main = Title,  # Titulo
             pch  = 15, # Formato dos pontos 
             cex  = 1,  # Tamanho dos pontos
             xlim = c(min(X)-0.1,max(X)+0.1), # Dimensao para as linhas do grafico
             ylim = c(min(cbind(Predicao,Inter.Conf[,2:3],Inter.Pred[,2:3])),max(cbind(Predicao,Inter.Conf[,2:3],Inter.Pred[,2:3]))+0.1), # Dimensao para as colunas do grafico
             col  = ifelse(Color,"red","black")) # Cor dos pontos
        
        
        ## Inicio - Acrescenta a reta ajustada
        lines(cbind(New.X,Predicao)) # acrescenta a reta ajustada
        ## Fim - Acrescenta a reta ajustada
        
        ## Inicio - Acrescenta o Intervalo de Confianca das previsoes
        if (IntConf) {
           lines(cbind(New.X,Inter.Conf[,2]), lty=3) # acrescenta I.C. Lim.Infereior
           lines(cbind(New.X,Inter.Conf[,3]), lty=3) # acrescenta I.C. Lim.Superior
        }
        ## Fim - Acrescenta o Intervalo de Confianca das previsoes
        
        ## Inicio - Acrescenta o Intervalo das previsoes
        if (IntPrev) {
           lines(cbind(New.X,Inter.Pred[,2]), lty=2) # acrescenta I.P. Lim.Infereior
           lines(cbind(New.X,Inter.Pred[,3]), lty=2) # acrescenta I.P. Lim.Superior
        }
        ## Fim - Acrescenta o Intervalo das previsoes
     }
  }
  ## Fim - Grafico da regressao
  
  ## Inicio - Grafico da probalidade normal
  if (TypeGraf == "QQPlot") {
    
     if (is.na(xlabel))
        xlabel = "Quantiles"  # Nomeia Eixo X  
    
     if (is.na(ylabel))
        ylabel = "Sample of the quantiles"  # Nomeia Eixo Y

     if (is.na(Title))
        Title = c("Graph of the normal probability\n of the residue")
     
     if (Casc) dev.new() # efeito cascata na apresentacao dos graficos
     
     qqnorm(Reg$Error,
            xlab = xlabel, # Nomeia Eixo X
            ylab = ylabel, # Nomeia Eixo Y
            main = Title,  # Titulo
            pch  = 19,     # Formato dos pontos 
            cex  = 1)
     qqline(Reg$Error, col = ifelse(Color,"red","black"))
  }
  ## Fim - Grafico da probalidade normal
  
  ## Inicio - Grafico da probalidade normal
  if (TypeGraf == "Histogram") {
    
     if (is.na(xlabel))
        xlabel = "Residue"  # Nomeia Eixo X  
    
     if (is.na(ylabel))
        ylabel = "Frequence"  # Nomeia Eixo Y
    
     if (is.na(Title))
        Title = c("Residue Histogram")
     
     if (Casc) dev.new() # efeito cascata na apresentacao dos graficos
     
     hist(Reg$Error,
          xlab = xlabel, # Nomeia Eixo X
          ylab = ylabel, # Nomeia Eixo Y
          main = Title,  # Titulo
          pch  = 19,     # Formato dos pontos 
          cex  = 1)
  }
  ## Fim - Grafico da probalidade normal
  
  ## Inicio - Grafico dos valores ajustados com os residuos
  if (TypeGraf == "Fits") {
    
    if (is.na(xlabel))
       xlabel = "Fits values"  # Nomeia Eixo X  
    
    if (is.na(ylabel))
       ylabel = "Residue"  # Nomeia Eixo Y
    
    if (is.na(Title))
       Title = c("Fits values vs. residues")
    
    if (Casc) dev.new() # efeito cascata na apresentacao dos graficos
    
    plot(Reg$Prev,Reg$Error, # cria grafico
         xlab = xlabel, # Nomeia Eixo X
         ylab = ylabel, # Nomeia Eixo Y
         main = Title,  # Titulo
         pch  = 19, # Formato dos pontos 
         cex  = 1,  # Tamanho dos pontos
         col  = ifelse(Color,"red","black"))  # Cor dos pontos
    
    abline(0,0, lty = 2) # acrescenta a reta do eixo X
  }
  ## Fim - Grafico dos valores ajustados com os residuos
  
  ## Inicio - Grafico com ordem das observacoes versus os residuos
  if (TypeGraf == "Order") {
    
    if (is.na(xlabel))
       xlabel = "Order of the observations"  # Nomeia Eixo X  
    
    if (is.na(ylabel))
       ylabel = "Residue" # Nomeia Eixo Y
    
    if (is.na(Title))
       Title = c("Order of the observations\n vs. residues")
    
    if (Casc) dev.new() # efeito cascata na apresentacao dos graficos
    
    plot(1:length(Reg$Error),Reg$Error, # cria grafico
         xlab = xlabel, # Nomeia Eixo X
         ylab = ylabel, # Nomeia Eixo Y
         main = Title,  # Titulo
         type = "o", # linhas com pontos
         pch  = 19,  # Formato dos pontos 
         cex  = 1,   # Tamanho dos pontos
         col  = ifelse(Color,"blue","black")) # Cor dos pontos
    
    abline(0,0, lty = 2) # acrescenta a reta do eixo X
  }
  ## Fim - Grafico com as ordem das observacoes versus os residuos

}

==> MVar_2.0.6.tar.gz: MVar/R/Plot.Regr_English.R <==
Plot.Regr <- function(Reg, TypeGraf = "Scatterplot", Title = NA, xlabel = NA, 
                      ylabel = NA, NameVarY = NA, NameVarX = NA, Color = TRUE, 
                      IntConf = TRUE, IntPrev = TRUE, Casc = TRUE) {
  # Esta funcao gera graficos da Analise de Regressao
  # desenvolvida por Paulo Cesar Ossani em 06/2016
    
  # Entrada:
  # Reg      - Dados da funcao de regressao.
  # TypeGraf - Tipo de grafico: 
  #            "Scatterplot" - Grafico de dispersao 2 a 2,
  #            "Regression"  - Grafico da regressao linear,
  #            "QQPlot"      - Grafico de probabilidade normal dos residuos,
  #            "Histogram"   - Histograma dos residuos,
  #            "Fits"        - Grafico dos valores ajustados versus os residuos,
  #            "Order"       - Grafico da ordem das observacoes versus os residuos.
  # Title    - Titulos para os graficos, se nulo retorna padrao.
  # xlabel   - Nomeia o eixo X, se nulo retorna padrao.
  # ylabel   - Nomeia o eixo Y, se nulo retorna padrao.
  # NameVarY - Nome da variavel Y, se nulo retorna padrao.
  # NameVarX - Nome da variavel, ou variaveis X, se nulo retorna padrao.
  # Color    - Graficos coloridos (default = TRUE).
  # IntConf  - Caso TypeGraf = "Regression":
  #            Graficos com intervalo de confianca (default = TRUE).
  # IntPrev  - Caso TypeGraf = "Regression":
  #            Graficos com intervalo de previsao (default = TRUE).
  # Casc    - Efeito cascata na apresentacao dos graficos (default = TRUE).

  # Retorna:
  # Varios graficos.

  Graphic <- c("Scatterplot", "Regression", "QQPlot", "Histogram", "Fits", "Order")
  if (is.na(pmatch(TypeGraf, Graphic))) 
     stop("'TypeGraf' input is incorrect, it should be: 'Scatterplot', 
          'Regression', 'QQPlot', 'Histogram', 'Fits' ou 'Order'. Verify!")

  if (!is.character(xlabel) && !is.na(xlabel[1]))
     stop("'xlabel' input is incorrect, it should be of type character or string. Verify!")
  
  if (!is.character(ylabel) && !is.na(ylabel[1]))
     stop("'ylabel' input is incorrect, it should be of type character or string. Verify!")
  
  if (!is.logical(Color))
     stop("'Color' input is incorrect, it should be TRUE or FALSE. Verify!")

  if (!is.logical(IntConf))
     stop("'IntConf' input is incorrect, it should be TRUE or FALSE. Verify!")

  if (!is.logical(IntPrev))
     stop("'IntPrev' input is incorrect, it should be TRUE or FALSE. Verify!")
 
  if (Reg$Intercepts) X <- as.matrix(Reg$X[,2:ncol(Reg$X)]) else X <- as.matrix(Reg$X)
  
  if (is.na(NameVarY[1]))
     NameVarY <- c("Y")
  
  if (is.na(NameVarX[1]))
     NameVarX <- c(paste("X",1:ncol(X),sep=""))
  
  if (!is.logical(Casc))
     stop("'Casc' input is incorrect, it should be TRUE or FALSE. Verify!")
  
  ## Inicio - Scatterplot
  if (TypeGraf == "Scatterplot") {
    
     if (is.na(Title[1]))
        Title = c("Scatterplot 2 to 2")
     
     if (Casc) dev.new() # efeito cascata na apresentacao dos graficos
     
     Dat <- as.data.frame(cbind(Reg$Y,X))
     colnames(Dat) <- c(NameVarY,NameVarX)
     if (Color) cor <- c(2:(ncol(X)+1)) else cor <- c(rep("black", ncol(X)))
     pairs(Dat, # Scatterplot
           main = Title, # Titulo
           pch  = 21,    # Formato dos pontos 
           cex  = 1,     # Tamanho dos pontos
           bg   = cor)
  }
  ## Fim - Scatterplot
  
  ## Inicio - Grafico da regressao
  if (TypeGraf == "Regression") {
     if (ncol(X)!=1) 
        print("Warning! The regression graph is only possible for a regressor variable.")
    
     if (ncol(X)==1) { # para calculos de regressao simples
        
        if (is.na(xlabel[1]))
           xlabel = "X-Axis"  # Nomeia Eixo X  
       
        if (is.na(ylabel[1]))
           ylabel = "Y-Axis"  # Nomeia Eixo Y
        
        if (is.na(Title[1]))
           Title = c("Linear regression graph")
        
        X <- as.numeric(X)
        
        if (Reg$Intercepts) Modelo <- lm(Y~X) else Modelo <- lm(Y~-1+X)
        
        if (Casc) dev.new() # efeito cascata na apresentacao dos graficos
        
        # Intervalo para abcissa
        Inter <- ifelse(length(Reg$Y)<100,150,length(Reg$Y)*1.5) # intervalo para o eixo X
        New.X <- data.frame(X=seq(min(X), max(X), by=((max(X)-min(X))/Inter)))
        
        # Predicao
        Predicao  <- predict(Modelo, New.X)
        
        # Intervalo de confianca
        Inter.Conf <- predict(Modelo, New.X, level=0.95, interval=c("confidence"))
        
        # Intervalo de Predicao
        Inter.Pred <- predict(Modelo, New.X, level=0.95, interval=c("prediction"))  
        
        plot(X,Reg$Y, # cria grafico
             xlab = xlabel, # Nomeia Eixo X
             ylab = ylabel, # Nomeia Eixo Y
             main = Title,  # Titulo
             pch  = 15, # Formato dos pontos 
             cex  = 1,  # Tamanho dos pontos
             xlim = c(min(X)-0.1,max(X)+0.1), # Dimensao para as linhas do grafico
             ylim = c(min(cbind(Predicao,Inter.Conf[,2:3],Inter.Pred[,2:3])),max(cbind(Predicao,Inter.Conf[,2:3],Inter.Pred[,2:3]))+0.1), # Dimensao para as colunas do grafico
             col  = ifelse(Color,"red","black")) # Cor dos pontos
        
        
        ## Inicio - Acrescenta a reta ajustada
        lines(cbind(New.X,Predicao)) # acrescenta a reta ajustada
        ## Fim - Acrescenta a reta ajustada
        
        ## Inicio - Acrescenta o Intervalo de Confianca das previsoes
        if (IntConf) {
           lines(cbind(New.X,Inter.Conf[,2]), lty=3) # acrescenta I.C. Lim.Infereior
           lines(cbind(New.X,Inter.Conf[,3]), lty=3) # acrescenta I.C. Lim.Superior
        }
        ## Fim - Acrescenta o Intervalo de Confianca das previsoes
        
        ## Inicio - Acrescenta o Intervalo das previsoes
        if (IntPrev) {
           lines(cbind(New.X,Inter.Pred[,2]), lty=2) # acrescenta I.P. Lim.Infereior
           lines(cbind(New.X,Inter.Pred[,3]), lty=2) # acrescenta I.P. Lim.Superior
        }
        ## Fim - Acrescenta o Intervalo das previsoes
     }
  }
  ## Fim - Grafico da regressao
  
  ## Inicio - Grafico da probalidade normal
  if (TypeGraf == "QQPlot") {
    
     if (is.na(xlabel[1]))
        xlabel = "Quantiles"  # Nomeia Eixo X  
    
     if (is.na(ylabel[1]))
        ylabel = "Sample of the quantiles"  # Nomeia Eixo Y

     if (is.na(Title[1]))
        Title = c("Graph of the normal probability\n of the residue")
     
     if (Casc) dev.new() # efeito cascata na apresentacao dos graficos
     
     qqnorm(Reg$Error,
            xlab = xlabel, # Nomeia Eixo X
            ylab = ylabel, # Nomeia Eixo Y
            main = Title,  # Titulo
            pch  = 19,     # Formato dos pontos 
            cex  = 1)
     qqline(Reg$Error, col = ifelse(Color,"red","black"))
  }
  ## Fim - Grafico da probalidade normal
  
  ## Inicio - Grafico da probalidade normal
  if (TypeGraf == "Histogram") {
    
     if (is.na(xlabel[1]))
        xlabel = "Residue"  # Nomeia Eixo X  
    
     if (is.na(ylabel[1]))
        ylabel = "Frequence"  # Nomeia Eixo Y
    
     if (is.na(Title[1]))
        Title = c("Residue Histogram")
     
     if (Casc) dev.new() # efeito cascata na apresentacao dos graficos
     
     hist(Reg$Error,
          xlab = xlabel, # Nomeia Eixo X
          ylab = ylabel, # Nomeia Eixo Y
          main = Title,  # Titulo
          pch  = 19,     # Formato dos pontos 
          cex  = 1)
  }
  ## Fim - Grafico da probalidade normal
  
  ## Inicio - Grafico dos valores ajustados com os residuos
  if (TypeGraf == "Fits") {
    
    if (is.na(xlabel[1]))
       xlabel = "Fits values"  # Nomeia Eixo X  
    
    if (is.na(ylabel[1]))
       ylabel = "Residue"  # Nomeia Eixo Y
    
    if (is.na(Title[1]))
       Title = c("Fits values vs. residues")
    
    if (Casc) dev.new() # efeito cascata na apresentacao dos graficos
    
    plot(Reg$Prev,Reg$Error, # cria grafico
         xlab = xlabel, # Nomeia Eixo X
         ylab = ylabel, # Nomeia Eixo Y
         main = Title,  # Titulo
         pch  = 19, # Formato dos pontos 
         cex  = 1,  # Tamanho dos pontos
         col  = ifelse(Color,"red","black"))  # Cor dos pontos
    
    abline(0,0, lty = 2) # acrescenta a reta do eixo X
  }
  ## Fim - Grafico dos valores ajustados com os residuos
  
  ## Inicio - Grafico com ordem das observacoes versus os residuos
  if (TypeGraf == "Order") {
    
    if (is.na(xlabel[1]))
       xlabel = "Order of the observations"  # Nomeia Eixo X  
    
    if (is.na(ylabel[1]))
       ylabel = "Residue" # Nomeia Eixo Y
    
    if (is.na(Title[1]))
       Title = c("Order of the observations\n vs. residues")
    
    if (Casc) dev.new() # efeito cascata na apresentacao dos graficos
    
    plot(1:length(Reg$Error),Reg$Error, # cria grafico
         xlab = xlabel, # Nomeia Eixo X
         ylab = ylabel, # Nomeia Eixo Y
         main = Title,  # Titulo
         type = "o", # linhas com pontos
         pch  = 19,  # Formato dos pontos 
         cex  = 1,   # Tamanho dos pontos
         col  = ifelse(Color,"blue","black")) # Cor dos pontos
    
    abline(0,0, lty = 2) # acrescenta a reta do eixo X
  }
  ## Fim - Grafico com as ordem das observacoes versus os residuos

}
